"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dbGet = exports.dbSet = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const config_1 = require("./config");
function dbPath() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const dir = yield (0, config_1.configDir)();
        return path.join(dir, "db.json");
    });
}
function write(data) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield fs.promises.writeFile(yield dbPath(), JSON.stringify(data, null, "  "));
    });
}
function read() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            return JSON.parse(yield fs.promises.readFile(yield dbPath(), "utf-8"));
        }
        catch (err) {
            return {};
        }
    });
}
function dbSet(key, value) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const db = yield read();
        db[key] = value;
        yield write(db);
    });
}
exports.dbSet = dbSet;
function dbGet(key, defaultValue) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const db = yield read();
        const value = db[key];
        if (value !== undefined) {
            return value;
        }
        return defaultValue;
    });
}
exports.dbGet = dbGet;
//# sourceMappingURL=db.js.map